==> sqlime3-1.0.0.tar.gz: sqlime3-1.0.0/sqlime3/__init__.py <==
"""
Модуль предоставляет классы для работы с базами данных SQLite.

Классы:
- ChildObject: Базовый класс для объектов, связанных с базой данных.
    - __init__(self, connection: Connection, parent):
        Инициализирует объект с подключением к базе данных и родительским объектом.
    - parent(self): Возвращает родительский объект.
    - find_parent(self, cls): Возвращает ближайший родительский объект указанного класса.

- Row: Класс, представляющий строку в таблице базы данных.
    - __init__(self, connection: Connection, parent: Rows, rowid: int):
        Инициализирует объект строки с подключением к базе данных, родительским объектом и идентификатором строки.
    - id(self) -> int: Возвращает идентификатор строки.
    - __len__(self): Возвращает количество столбцов в строке.
    - __getitem__(self, item): Возвращает значение столбца в строке по индексу или имени.
    - __setitem__(self, key, value): Устанавливает значение столбца в строке по индексу или имени.
    - __delitem__(self, key): Удаляет значение столбца в строке по индексу или имени.
    - __contains__(self, item): Проверяет наличия элемента в объекте.
    - __iter__(self): Возвращает итератор по значениям столбцов в строке.
    - __repr__(self): Возвращает строковое представление объекта строки.

- Rows: Класс, представляющий набор строк в таблице базы данных.
    - __init__(self, connection: Connection, parent: Table):
        Инициализирует объект набора строк с подключением к базе данных и родительским объектом.
    - insert(self, values=None, columns=None, data=None) -> None: Вставляет новую строку в таблицу.
    - __len__(self): Возвращает количество строк в таблице.
    - __getitem__(self, item): Возвращает строку по индексу, значению или диапазону.
    - __setitem__(self, *columns, values): Вставляет новую строку в таблицу.
    - __delitem__(self, key): Удаляет строку по индексу, значению или диапазону.
    - __contains__(self, item): Проверяет наличия элемента в объекте.
    - __iter__(self): Возвращает итератор по строкам в таблице.
    - __repr__(self): Возвращает строковое представление объекта набора строк.

- Column: Класс, представляющий столбец в таблице базы данных.
    - __init__(self, connection: Connection, parent: Columns, cid: int):
        Инициализирует объект столбца с подключением к базе данных, родительским объектом и идентификатором столбца.
    - pragma(self) -> tuple: Возвращает информацию о столбце.
    - id(self) -> int: Возвращает идентификатор столбца.
    - name(self) -> str: Возвращает имя столбца.
    - type(self) -> str: Возвращает тип данных столбца.
    - not_null(self) -> bool: Возвращает, является ли столбец NOT NULL.
    - default(self) -> any: Возвращает значение по умолчанию столбца.
    - pk(self) -> bool: Возвращает, является ли столбец первичным ключом.
    - __repr__(self): Возвращает строковое представление объекта столбца.

- Columns: Класс, представляющий набор столбцов в таблице базы данных.
    - __init__(self, connection: Connection, parent: Table): 
        Инициализирует объект набора столбцов с подключением к базе данных и родительским объектом.
    - pragma(self) -> list[tuple]: Возвращает информацию о столбцах.
    - names(self) -> tuple[str, ...]: Возвращает имена столбцов.
    - __len__(self): Возвращает количество столбцов.
    - __getitem__(self, item): Возвращает столбец по индексу, имени или диапазону.
    - __setitem__(self, key, value): Не поддерживается.
    - __delitem__(self, key): Не поддерживается.
    - __contains__(self, item): Проверяет наличия элемента в объекте.
    - __iter__(self): Возвращает итератор по столбцам.
    - __repr__(self): Возвращает строковое представление объекта набора столбцов.

- Table: Класс, представляющий таблицу в базе данных.
    - __init__(self, connection: Connection, parent: Lime, name: str): 
        Инициализирует объект таблицы с подключением к базе данных, родительским объектом и именем таблицы.
    - sql(self) -> str: Возвращает SQL-команду для создания таблицы.
    - name(self) -> str: Возвращает имя таблицы.
    - columns(self) -> Columns: Возвращает объект Columns, представляющий столбцы таблицы.
    - rows(self) -> Rows: Возвращает объект Rows, представляющий строки таблицы.
    - primary_key(self) -> tuple[str, ...]: Возвращает первичный ключ таблицы.
    - foreign_keys(self) -> list[tuple]: Возвращает внешние ключи таблицы.
    - __repr__(self): Возвращает строковое представление объекта таблицы.

- Lime: Класс, представляющий базу данных.
    - __init__(self, connection: Connection): Инициализирует объект базы данных с подключением к базе данных.
    - sql(self) -> tuple[str, ...]: Возвращает SQL-команды для создания всех таблиц в базе данных.
    - names(self) -> tuple[str, ...]: Возвращает имена всех таблиц в базе данных.
    - __len__(self): Возвращает количество таблиц в базе данных.
    - __getitem__(self, item): Возвращает таблицу по индексу, имени или диапазону.
    - __setitem__(self, key, value): Создает новую таблицу в базе данных.
    - __delitem__(self, key): Удаляет таблицу из базы данных.
    - __contains__(self, item): Проверяет наличия элемента в объекте.
    - __iter__(self): Возвращает итератор по таблицам в базе данных.
    - __repr__(self): Возвращает строковое представление объекта базы данных.
"""

==> sqlime3-1.2.0.tar.gz: sqlime3-1.2.0/sqlime3/__init__.py <==
"""
Модуль предоставляет классы для работы с базами данных SQLite.

Классы:
- ChildObject: Базовый класс для объектов, связанных с базой данных.
    - __init__(self, connection: Connection, parent):
        Инициализирует объект с подключением к базе данных и родительским объектом.
    - parent(self): Возвращает родительский объект.
    - find_parent(self, cls): Возвращает ближайший родительский объект указанного класса.

- Row: Класс, представляющий строку в таблице базы данных.
    - __init__(self, connection: Connection, parent: Rows, rowid: int):
        Инициализирует объект строки с подключением к базе данных, родительским объектом и идентификатором строки.
    - id(self) -> int: Возвращает идентификатор строки.
    - __len__(self): Возвращает количество столбцов в строке.
    - __getitem__(self, item): Возвращает значение столбца в строке по индексу или имени.
    - __setitem__(self, key, value): Устанавливает значение столбца в строке по индексу или имени.
    - __delitem__(self, key): Удаляет значение столбца в строке по индексу или имени.
    - __contains__(self, item): Проверяет наличия элемента в объекте.
    - __iter__(self): Возвращает итератор по значениям столбцов в строке.
    - __repr__(self): Возвращает строковое представление объекта строки.

- Rows: Класс, представляющий набор строк в таблице базы данных.
    - __init__(self, connection: Connection, parent: Table):
        Инициализирует объект набора строк с подключением к базе данных и родительским объектом.
    - insert(self, values=None, columns=None, data=None) -> None: Вставляет новую строку в таблицу.
    - remove(self, key): Удаляет строку из таблицы.
    - __len__(self): Возвращает количество строк в таблице.
    - __getitem__(self, item): Возвращает строку по индексу, значению или диапазону.
    - __contains__(self, item): Проверяет наличия элемента в объекте.
    - __iter__(self): Возвращает итератор по строкам в таблице.
    - __repr__(self): Возвращает строковое представление объекта набора строк.

- Column: Класс, представляющий столбец в таблице базы данных.
    - __init__(self, connection: Connection, parent: Columns, cid: int):
        Инициализирует объект столбца с подключением к базе данных, родительским объектом и идентификатором столбца.
    - pragma(self) -> tuple: Возвращает информацию о столбце.
    - id(self) -> int: Возвращает идентификатор столбца.
    - name(self) -> str: Возвращает имя столбца.
    - type(self) -> str: Возвращает тип данных столбца.
    - not_null(self) -> bool: Возвращает, является ли столбец NOT NULL.
    - default(self) -> any: Возвращает значение по умолчанию столбца.
    - pk(self) -> bool: Возвращает, является ли столбец первичным ключом.
    - __repr__(self): Возвращает строковое представление объекта столбца.

- Columns: Класс, представляющий набор столбцов в таблице базы данных.
    - __init__(self, connection: Connection, parent: Table): 
        Инициализирует объект набора столбцов с подключением к базе данных и родительским объектом.
    - pragma(self) -> list[tuple]: Возвращает информацию о столбцах.
    - names(self) -> tuple[str, ...]: Возвращает имена столбцов.
    - __len__(self): Возвращает количество столбцов.
    - __getitem__(self, item): Возвращает столбец по индексу, имени или диапазону.
    - __contains__(self, item): Проверяет наличия элемента в объекте.
    - __iter__(self): Возвращает итератор по столбцам.
    - __repr__(self): Возвращает строковое представление объекта набора столбцов.

- Table: Класс, представляющий таблицу в базе данных.
    - __init__(self, connection: Connection, parent: Lime, name: str): 
        Инициализирует объект таблицы с подключением к базе данных, родительским объектом и именем таблицы.
    - sql(self) -> str: Возвращает SQL-команду для создания таблицы.
    - name(self) -> str: Возвращает имя таблицы.
    - columns(self) -> Columns: Возвращает объект Columns, представляющий столбцы таблицы.
    - rows(self) -> Rows: Возвращает объект Rows, представляющий строки таблицы.
    - primary_key(self) -> tuple[str, ...]: Возвращает первичный ключ таблицы.
    - foreign_keys(self) -> list[tuple]: Возвращает внешние ключи таблицы.
    - __repr__(self): Возвращает строковое представление объекта таблицы.

- Lime: Класс, представляющий базу данных.
    - __init__(self, connection: Connection): Инициализирует объект базы данных с подключением к базе данных.
    - sql(self) -> tuple[str, ...]: Возвращает SQL-команды для создания всех таблиц в базе данных.
    - names(self) -> tuple[str, ...]: Возвращает имена всех таблиц в базе данных.
    - __len__(self): Возвращает количество таблиц в базе данных.
    - __getitem__(self, item): Возвращает таблицу по индексу, имени или диапазону.
    - create(self, name, value): Создает новую таблицу в базе данных.
    - delete(self, key): Удаляет таблицу из базы данных.
    - __contains__(self, item): Проверяет наличия элемента в объекте.
    - __iter__(self): Возвращает итератор по таблицам в базе данных.
    - __repr__(self): Возвращает строковое представление объекта базы данных.
"""
